#
# spec file for package pingus
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{?suse_version} > 1210
%define with_wiimote False
%else
%define with_wiimote True
%endif
Name:           pingus
Version:        0.7.6
Release:        18.4
Summary:        Free Lemmings-like puzzle game
License:        GPL-3.0-or-later
Group:          Amusements/Games/Logic
URL:            https://pingus.seul.org/
# Downloaded from https://code.google.com/p/pingus/source/checkout
# Packed as tar.bz2
Source0:        %{name}-%{version}+git-6a1153a.tar.bz2
# PATCH-FIX-UPSTREAM Issue 136, Add .desktop file to source package
Source1:        https://gitlab.com/pingus/pingus/-/raw/dddd6be31a04d7cadd71ca6e5d3e292d73c270c9/%{name}.desktop
# PATCH-FEATURE-UPSTREAM
Source2:        https://gitlab.com/pingus/pingus/-/raw/62e3f61ad704563e09d0a2ed8f4d369ba5a0167e/%{name}.appdata.xml
# PATCH-FIX-UPSTREAM pingus-0.7.6-Makefile.patch -- Issue 144, use /usr for prefix, fix man, permissions
Patch1:         %{name}-%{version}-Makefile.patch
# PATCH-FIX-UPSTREAM pingus-0.7.6-SConscript.patch -- Issue 145, Fix linking against X11 and adds wii support
Patch2:         %{name}-%{version}-SConscript.patch
# PATCH-FIX-UPSTREAM pingus-scons-on-py3.patch dimstar@opensuse.org -- Fix build with scons using python3 as interpreter
Patch3:         pingus-scons-on-py3.patch
# PATCH-FIX-OPENSUSE pingus-gcc13.patch munix9@googlemail.com -- Fix build with gcc 13
Patch4:         pingus-gcc13.patch
BuildRequires:  bluez-devel
BuildRequires:  dos2unix
BuildRequires:  gcc-c++
BuildRequires:  libpng-devel
BuildRequires:  pkgconfig
BuildRequires:  scons
BuildRequires:  pkgconfig(SDL_image)
BuildRequires:  pkgconfig(SDL_mixer)
BuildRequires:  pkgconfig(xi)
%if 0%{?suse_version}
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  update-desktop-files
%endif
%if 0%{?suse_version} > 1325
BuildRequires:  libboost_headers-devel
%else
BuildRequires:  boost-devel
%endif

%description
Pingus is a free Lemmings-like puzzle game covered under the GNU GPL.
It features currently 77 playable levels.

You can use to see which languages are supported

    pingus --list-languages

And start with

    pingus --language de

If you wish to play the other levels

    pingus %{_datadir}/pingus/levels/playable/some-level
    pingus %{_datadir}/pingus/levels/incoming/some-level
    pingus %{_datadir}/pingus/levels/wip/some-level

The other, probably more userfriendly, way is to simply load them into
the level editor and then click the play button.

%prep
%setup -q -n %{name}
%patch -P 1
%patch -P 2
%patch -P 3 -p1
%patch -P 4 -p1

# Convert to unix line end
dos2unix data/po/pl.po data/levels/incoming/*.pingus \
         data/images/pingus/README

# SED-FIX-UPSTREAM -- Issue 144, Fix datadir
sed -i 's|set_path("data")|set_path("%{_datadir}/%{name}")|' \
    src/pingus/pingus_main.cpp

# SED-FIX-UPSTREAM -- Issue 145, Fix linking against X11
sed -i 's|'SDL_mixer', 'png'|'SDL_mixer', 'png', 'X11'|' \
    src/engine/input/SConstruct.main

# SED-FIX-UPSTREAM -- Issue 146, Remove debug, add missing includes and allow wii support to compile
sed -i -e 's|"pingus/debug.hpp"|<iostream>|' \
    -i -e '/pout(PINGUS_DEBUG_INPUT)/d' \
    src/engine/input/xinput/xinput_driver.cpp
sed -i -e :a -e '\%/#include "engine/input/xinput/xinput_driver.hpp"%!b' \
    -e $'n;/namespace Input {/i\\\n#include <iostream>' -e ba src/engine/input/xinput/xinput_device.cpp
sed -i -e 's|"pingus/debug.hpp"|<iostream>|' \
    -i -e '/WiimoteDriver: (wiimote:button/,+2d' \
    -i -e '/WiimoteDriver: (wiimote:axis/,+3d' \
    src/engine/input/wiimote/wiimote_driver.cpp

%build
mkdir -p build
scons %{?_smp_mflags} CCFLAGS="%{optflags}" with_wiimote=%{with_wiimote} \
      with_linuxusbmouse=True with_linuxevdev=True with_xinput=True

%install
%make_install

install -Dm 0644 data/images/icons/pingus.png %{buildroot}/%{_datadir}/icons/hicolor/32x32/apps/%{name}.png
install -Dm 0644 data/images/icons/pingus-icon.png %{buildroot}/%{_datadir}/icons/hicolor/48x48/apps/%{name}.png
install -Dm 0644 data/images/icons/pingus.svg %{buildroot}/%{_datadir}/icons/hicolor/scalable/apps/%{name}.svg

install -Dm 0644 %{SOURCE1} %{buildroot}%{_datadir}/applications/%{name}.desktop

install -Dm 0644 %{SOURCE2} %{buildroot}%{_datadir}/metainfo/%{name}.appdata.xml

%if 0%{?suse_version}
    %suse_update_desktop_file %{name}
    %fdupes -s %{buildroot}%{_prefix}
%endif

%files
%license COPYING
%doc AUTHORS NEWS README TODO
%{_bindir}/%{name}
%{_mandir}/man6/%{name}.6%{?ext_man}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/metainfo/%{name}.appdata.xml
%{_datadir}/icons/hicolor/*/apps/%{name}.*
%{_datadir}/%{name}

%changelog
* Thu Feb 29 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN.
* Wed Apr 12 2023 munix9@googlemail.com
- Add pingus-gcc13.patch: Fix build with gcc 13
* Sun Jan 31 2021 Matthias Mailänder <matthias@mailaender.name>
- Add https://en.opensuse.org/openSUSE:AppStore metadata
- Use upstream .desktop file
- Fix icon file ending
* Fri Mar  6 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Drop libcwiid-devel BuildRequires: cwiid is deprecated and no
  longer maintained in openSUSE.
* Thu Nov 23 2017 dimstar@opensuse.org
- Add pingus-scons-on-py3.patch: Fix build with scons using
  python3 as interpreter.
* Thu Feb  2 2017 adam.majer@suse.de
- use individual libboost-*-devel packages instead of boost-devel
* Thu Dec 11 2014 nemysis@gmx.ch
- Change Desktop entry
- Remove icon pingus.png, use supplied icons
- Change Summary abd Group
- Download from Google Code and packed as tar.bz2
- Remove obsolete patch pingus-gcc47.patch, changed by upstream
- Use sed instead of simple patches pingus-cwiid_with_bluez.patch,
  dsolink.patch, remove-debug_fix-includes.patch and
  makefile-fixes.patch
- Add patches pingus-0.7.6-Makefile.patch and
  pingus-0.7.6-SConscript.patch
- Use check for openSUSE %%if 0%%{?suse_version}
- Add BuildRequires for hicolor-icon-theme, dos2unix and
  pkgconfig(xi)
- Use BuildRequires pkgconfig() instead of devel packages
- Change Description
* Sun Mar 25 2012 dimstar@opensuse.org
- Add pingus-gcc47.patch: Fix build with gcc 4.7.
- Disable wiimote support (using a with_wiimote define) for now on
  openSUSE > 12.1, as bluez needs to be fixed first.
* Thu Jan 26 2012 dbuck@novell.com
- Update to 0.7.6
  * added new SVG icons for Pingus
  * added 10 new xmas themed levels
  * added ability to sort levelsets by priority
* Wed Nov  9 2011 saschpe@suse.de
- Spec file cleanup:
  * run spec-cleaner
  * run fdupes
  * fix executable bits for stuff in /usr/share/pingus
* Thu Nov  3 2011 dbuck@novell.com
- update to 0.7.5
  * fixed memory leak in OpenGL renderer
  * added support for Win32 cross-compilation with mingw32
  * added gamespeed adjustments via KPPlus, KPMinus, KPEnter
  * added single-stepping the game with 'S'
  * added better application icon
  * added access to all levelsets in developer-mode (Ctrl-m)
  * added 10 new Halloween levels
* Wed Oct 12 2011 dbuck@novell.com
- update to 0.7.4
  * fixed game not starting when no soundcard is present
  * all halloween and tutorial levels have been converted to a minimum size of 1920x1200 so they can be played in fullscreen without letterboxing
  * new --userdir command line switch to set the directory where savegames are saved
  * menu getting confused by fast succedding clicks fixed
  * level-demo recording and playback are back (files not compatible between x86 and x86-64)
  * window resize support throughout the whole game
  * dirty-rectangles drawing for improved performance with software rendering
  * OpenGL rendering
  * new blackboard graphic
  * Unicode support
  * two new levelsets, "Desert" and "Factory Campaign", with 27 new levels
  * added a man-page
  * deadly fall height has been increased
  * support for prefab objects and groups in the editor
  * cleaned up digger, miner and basher paths
  * added an option menu
  * lots of minor bug fixes
  * bitmap fonts have been generated with anti-aliasing
- update patch set
  * removed gcc46.patch (included in update)
  * added makefile-fixes.patch and remove-debug_fix-includes.patch
  * updated dsolink.patch and pingus-cwiid_with_bluez.patch
- clean SPEC a bit
* Mon Sep  5 2011 meissner@suse.de
- fix build with --dt-needed...
* Thu Jul  7 2011 cwh@novell.com
- fixed build for gcc46
* Sat Jul 31 2010 pascal.bleser@opensuse.org
- update to 0.7.3
- add Wiimote support (with libcwiid)
* Wed Jun  3 2009 coolo@novell.com
- fix build with gcc 4.4
* Tue Mar  3 2009 crrodriguez@suse.de
- fix buildrequires
* Fri Nov 30 2007 prusnak@suse.cz
- update to 0.7.2
  * added support for levelsets
  * added 8 new levels in the form of a halloween levelset
  * added window resize support to the editor (use --allow-resize)
  * added minimap to the editor
  * scroll wheel support to change the actions
  * right and middle button now both scroll
  * 'jumper dying on landing' bug fixed
  * numerous other small bug fixes
- removed obsoleted patch
  * stdlib_string.patch (included in update)
* Thu Oct 18 2007 prusnak@suse.cz
- added missing include (stdlib_string.patch)
* Tue Oct  9 2007 prusnak@suse.cz
- update to 0.7.1
  * faster sprite drawing, so more overall fps
  * level editor rewritten from scratch
  * level loading from command line fixed
  * numerous other command line parsing bugs fixed
  * separate images for gfx and colmap are used again
  * input subsystem rewritten from scratch, supports now gamepads,
    usbmice, wiimote (some of those might unfinished and not enabled by
    default)
* Tue Sep  4 2007 prusnak@suse.cz
- updated to 0.7.0 (first SDL version)
  * switch from ClanLib to SDL
  * new anti-aliased fonts
  * better support for resolutions larger then 800x600 (see --geometry WxH option)
  * s-expression based file format (converter scripts are available)
  * PPC and 64bit support
  * language support for Czech, German, Finish, Italian, Norwegian,
    Serbian, Turkish, Danish, Dutch, Spanish and Fench
  * level editor temporarly removed
  * a little less fps then the ClanLib version
  * no new levels or other main features
* Wed Jun  6 2007 prusnak@suse.cz
- modified Makefile.in to accept DESTDIR (destdir.patch)
- cleaned spec file
* Thu Apr 12 2007 ro@suse.de
- added libmikmod-devel to buildreq
* Tue Sep 12 2006 dmueller@suse.de
- don't set -save-temps in a spec file
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Apr 20 2005 nadvornik@suse.de
- fixed to compile with gcc4
* Tue Nov  9 2004 sndirsch@suse.de
- pingus-snow11.diff: fixed wrong level description (Bug #47953)
* Wed Jul 21 2004 schwab@suse.de
- Fix use of size_type.
* Sat Jan 10 2004 adrian@suse.de
- add %%defattr
* Tue Sep 23 2003 sndirsch@suse.de
- fixed category; should be Arcade instead of Puzzle (Bug #31608)
* Wed Sep  3 2003 adrian@suse.de
- disable KDE wait cursor blinking on startup
* Sat Aug 30 2003 sndirsch@suse.de
- added desktop icon
* Sun Aug 10 2003 sndirsch@suse.de
- added desktop file
* Tue May 13 2003 ro@suse.de
- run autoreconf
* Mon Apr 21 2003 sndirsch@suse.de
- updated to version 0.6 - announced as first playable version!
* Tue Feb 25 2003 aj@suse.de
- Add missing assert include.
* Tue Feb 11 2003 nadvornik@suse.cz
- added install_info macros
* Thu Nov 21 2002 ro@suse.de
- removed duplicates in output files of configure.in
* Tue Nov  5 2002 ro@suse.de
- use correct include path for libxml
* Sat Jun  1 2002 ro@suse.de
- changed neededforbuild <libmikmo> to <libmikmod>
* Tue May  7 2002 ro@suse.de
- make it compile with current gcc-3.1 snapshot
* Tue May  7 2002 ro@suse.de
- added <libmikmo> <DirectFB> to neededforbuild
* Fri Apr 12 2002 ro@suse.de
- build with gcc-3.1
* Thu Jan 31 2002 ro@suse.de
- changed neededforbuild <libpng> to <libpng-devel-packages>
* Thu Jan 24 2002 ro@suse.de
- up to pre3 to make it build with latest clanlib
- (doesn't seem to use artsd at all anyway ...)
* Tue Jan 22 2002 ro@suse.de
- changed neededforbuild <kdelibs-artsd> to <kdelibs3-artsd>
* Tue Nov 20 2001 nadvornik@suse.cz
- added suse_update_config
* Sat Sep 22 2001 sndirsch@suse.de
- RPM Group tag set to Amusements/Games, so it can be found easier
* Wed Aug 29 2001 sndirsch@suse.de
- added pingus.sh
* Wed Aug  8 2001 ro@suse.de
- changed neededforbuild <sdl> to <SDL>
- changed neededforbuild <sdl-devel> to <SDL-devel>
* Mon Jul 30 2001 nadvornik@suse.cz
- update to 0.5.0pre2
* Mon Oct  9 2000 nadvornik@suse.cz
- fixed Copyright
* Thu Apr 13 2000 nadvornik@suse.cz
- added BuildRoot
* Fri Feb 18 2000 sndirsch@suse.de
- updated to release 0.3.1
* Wed Feb  9 2000 sndirsch@suse.de
- changed group tag
* Thu Jan 20 2000 sndirsch@suse.de
- moved /usr/man/*,/usr/info/* to /usr/share/man and /usr/share/info
* Tue Jan  4 2000 sndirsch@suse.de
- update to release 0.3.0a
* Mon Jan  3 2000 sndirsch@suse.de
- adjusted to new clanlib package
* Thu Dec 23 1999 sndirsch@suse.de
- updated to pingus 0.2.4, ClanLib 0.2.3 and Hermes 1.2.6
- removed OpenPTC, SVGALIB, FBDEV and GLX support (never worked)
- now only the necessary files are included
* Sun Oct  3 1999 sndirsch@suse.de
- updated to pingus 0.2.3 and ClanLib 0.1.19
- the patch against ClanLib is not required any more
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Mon Aug 30 1999 ro@suse.de
- asm parts only used on x86
- no sa_restorer on alpha
* Fri Jul 16 1999 sndirsch@suse.de
- updated pingus sources to version 0.1.1, now there are 5 levels playable
- updated OpenPTC sources to version 1.0.0-2
* Fri Jun 11 1999 sndirsch@suse.de
- updated pingus sources to version 0.0.15
- updated clanlib sources to version 0.1.15
- updated hermes sources to version 1.2.5
* Tue May 11 1999 sndirsch@suse.de
- updated package to release 0.0.14 (now two additional levels)
* Mon May 10 1999 sndirsch@suse.de
- created SPEC file
